@@ -68,14 +68,14 @@ function (L, earth.node, input.node)
     rownames(edges) <- NULL
     colnames(edges) <- c("from", "to")
     volts <- resistance(L, earth.node = earth.node, input.node = input.node, 
-        g = TRUE)
+        give.pots = TRUE)
     cbind(edges, (volts[edges[, 1]] - volts[edges[, 2]]) * L[edges])
 }
 "currents.matrix" <-
 function (L, earth.node, input.node) 
 {
     out <- L
-    out[] <- resistance(L, earth.node, input.node, g = TRUE)
+    out[] <- resistance(L, earth.node, input.node, give.pots = TRUE)
     out <- L * (out - t(out))
     out
 }
@@ -253,14 +253,13 @@ function (L)
 
   jj <- as.matrix(expand.grid(rep(list(0:1),n))) 
   
-  wrapper <- function(x, y) {
-    f <- function(x,y,tol=1e-4){
-      abs(sum(abs(jj[x,]-jj[y,]))-1)<tol
-    }
-    sapply(seq(along = x), FUN = function(i){f(x[i], y[i])})
-  }
-  
-  o <- -outer(1:(2^n),1:(2^n), wrapper)
+  o <-
+    -apply(jj, 1, function(y) {
+      apply(jj, 1, function(x) {
+        sum(x!=y)==1
+      })
+    })
+
   jj.names <- apply(jj,1,paste,collapse="")
   rownames(o) <- jj.names
   colnames(o) <- jj.names
